@@ -3,6 +3,16 @@ import sys
 import subprocess
 
 
+def set_current_task(description=''):
+    returncode = subprocess.call([
+        't',
+        'change',
+        description
+    ])
+    if returncode != 0:
+        print "You are not currently clocked-in"
+
+
 def main(stdin):
     lines = stdin.split('\n')
     original = json.loads(lines[0])
@@ -10,19 +20,12 @@ def main(stdin):
 
     if 'start' in original and 'start' not in modified:
         # Stop tracking time to this task.
-        subprocess.Popen([
-            't',
-            'change',
-        ])
+        set_current_task()
     elif 'start' in modified and 'start' not in original:
         # Start tracking time to this task.
-        subprocess.Popen([
-            't',
-            'change',
-            modified['description']
-        ])
+        set_current_task(modified['description'])
 
-    return ''
+    return json.dumps(modified)
 
 
 def cmdline():
